# -*- coding: utf-8 -*-

"""Top-level package for Typed Environment Configuration."""

__author__ = """Eugene Dementyev"""
__email__ = "eugene@springload.co.nz"
__version__ = "0.1.0"

from .typed_environment_configuration import *
